#!/bin/bash
host=`hostname -s | tr [:lower:] [:upper:]`

if [ ! -d "/home/phpchk/public_html/yj/" ]; then
    mkdir -p "/home/phpchk/public_html/yj"
    chown phpchk:phpchk /home/phpchk/public_html/yj

    if [ ! -f "/home/phpchk/public_html/yj/.htaccess" ]; then
        touch /home/phpchk/public_html/yj/.htaccess
        echo "deny from all" >> /home/phpchk/public_html/yj/.htaccess
        echo "allow from 103.129.168.88" >> /home/phpchk/public_html/yj/.htaccess
	chown phpchk:phpchk /home/phpchk/public_html/yj/.htaccess
    fi
fi


DOC_ROOT="/home/phpchk/public_html/yj"
CURRENT_FILE="$DOC_ROOT/${host}_current_data.txt"
PREVIOUS_FILE="$DOC_ROOT/${host}_previous_data.txt"
DIFF_FILE="$DOC_ROOT/${host}_difference.txt"
FULL_SYNC_FILE="$DOC_ROOT/${host}_current_data_full_sync.txt"

# 取得最新資料，生成 CSV 格式
DATA=$(whmapi1 --output=jsonpretty get_domain_info | jq -r '.data.domains[] | "\(.domain),\(.user),\(.user_owner),\(.domain_type),\(.docroot)"')
echo "$DATA" > "$CURRENT_FILE"

# 將當前數據排序，保存為 FULL_SYNC_FILE
sort "$CURRENT_FILE" > "$FULL_SYNC_FILE"

# 如果之前的文件不存在，初始化它
if [ ! -f "$PREVIOUS_FILE" ]; then
    touch "$PREVIOUS_FILE"
fi
sort "$PREVIOUS_FILE" -o "$PREVIOUS_FILE"

# 比較變化並生成差異文件
awk -F, 'BEGIN { OFS="," }
    NR==FNR {
        old[$1]=$0; # 使用 domain 作為鍵，保存整行數據
        next
    }
    {
        if (!($1 in old)) {
            print "A," $0; # 新增
        } else {
            split(old[$1], fields, ",");
            # 比較字段，判斷是否需要更新
            if (fields[2] != $2 || fields[3] != $3 || fields[4] != $4 || fields[5] != $5) {
                print "U," $0; # 更新
            }
        }
        delete old[$1]; # 已處理的記錄從 old 中刪除
    }
    END {
        for (domain in old) {
            print "D," domain; # 刪除
        }
    }
' "$PREVIOUS_FILE" "$FULL_SYNC_FILE" > "$DIFF_FILE"

# 如果差異文件有內容，才更新 previous_file
if [ -s "$DIFF_FILE" ]; then
    cp "$FULL_SYNC_FILE" "$PREVIOUS_FILE"
    echo "差異文件已生成：$DIFF_FILE"
else
    rm -f "$DIFF_FILE"
    echo "無差異，未生成差異文件。"
fi


chown phpchk:phpchk /home/phpchk/public_html/yj/  -R
